summaryrefslogtreecommitdiff
path: root/solenv
diff options
context:
space:
mode:
Diffstat (limited to 'solenv')
-rw-r--r--solenv/clang-format/ClangFormat.pm22
-rw-r--r--solenv/clang-format/README4
-rwxr-xr-xsolenv/clang-format/check-last-commit6
-rw-r--r--solenv/clang-format/excludelist (renamed from solenv/clang-format/blacklist)0
-rwxr-xr-xsolenv/clang-format/generate-style-excludelist (renamed from solenv/clang-format/generate-style-blacklist)4
-rwxr-xr-xsolenv/clang-format/reformat-formatted-files6
-rw-r--r--solenv/gbuild/extensions/post_GbuildToJson.mk8
7 files changed, 25 insertions, 25 deletions
diff --git a/solenv/clang-format/README b/solenv/clang-format/README
index 7d6407a35626..fc3a8be91bd6 100644
--- a/solenv/clang-format/README
+++ b/solenv/clang-format/README
@@ -20,7 +20,7 @@ Style enforcing code.
== Directory contents ==
-- blacklist: list of existing files not to be formatted:
+- excludelist: list of existing files not to be formatted:
- if you rename a file mentioned in this list, please update the entry (and
keep the file sorted)
@@ -29,7 +29,7 @@ Style enforcing code.
- ClangFormat.pm: shared code between the git hook and these scripts
-- generate-style-blacklist: was used to generate `blacklist`
+- generate-style-excludelist: was used to generate `excludelist`
- reformat-formatted-files: run this script in case the style config changes or
clang-format version is updated
diff --git a/solenv/clang-format/check-last-commit b/solenv/clang-format/check-last-commit
index 57939815bb0a..0de5ac4b0783 100755
--- a/solenv/clang-format/check-last-commit
+++ b/solenv/clang-format/check-last-commit
@@ -26,7 +26,7 @@ sub check_style()
my $src = ClangFormat::get_extension_regex();
my @good_names = ();
my @bad_names = ();
- my $blacklist_names = ClangFormat::get_blacklist();
+ my $excluded_list_names = ClangFormat::get_excludelist();
my $clang_format = ClangFormat::find();
my $parent = $commit + 1;
@@ -38,7 +38,7 @@ sub check_style()
while (my $filename = <FILES>)
{
chomp $filename;
- if ($filename =~ /\.($src)$/ and !exists($blacklist_names->{$filename}))
+ if ($filename =~ /\.($src)$/ and !exists($excluded_list_names->{$filename}))
{
if (! -x $clang_format)
{
@@ -67,7 +67,7 @@ sub check_style()
print("and the clang-format rules. Tips:\n");
print("\n- You may run '/opt/lo/bin/clang-format -i <problematic file>' to fix up style automatically.\n");
print("- See solenv/clang-format/README on where to get the required version of clang-format binaries.\n");
- print("- If you renamed a blacklisted file, update solenv/clang-format/blacklist accordingly to keep it blacklisted.\n");
+ print("- If you renamed an excluded file, update solenv/clang-format/excludelist accordingly to keep it excluded.\n");
print("\nsolenv/clang-format/check-last-commit: KO\n");
exit(1);
}
diff --git a/solenv/clang-format/blacklist b/solenv/clang-format/excludelist
index eda629a26010..eda629a26010 100644
--- a/solenv/clang-format/blacklist
+++ b/solenv/clang-format/excludelist
diff --git a/solenv/clang-format/generate-style-blacklist b/solenv/clang-format/generate-style-excludelist
index 60e7d277c6e7..b34b2041dea2 100755
--- a/solenv/clang-format/generate-style-blacklist
+++ b/solenv/clang-format/generate-style-excludelist
@@ -5,7 +5,7 @@
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
-# Generates a blacklist containing all existing cxx/hxx files.
+# Generates an excludelist containing all existing cxx/hxx files.
use strict;
use warnings;
@@ -26,6 +26,6 @@ while (my $filename = <FILES>)
}
}
-ClangFormat::set_blacklist(\@filenames);
+ClangFormat::set_excludelist(\@filenames);
# vim: set shiftwidth=4 softtabstop=4 expandtab:
diff --git a/solenv/clang-format/reformat-formatted-files b/solenv/clang-format/reformat-formatted-files
index 04b0adde8e4e..0302d3f9b244 100755
--- a/solenv/clang-format/reformat-formatted-files
+++ b/solenv/clang-format/reformat-formatted-files
@@ -5,7 +5,7 @@
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
-# Reformat files which are not blacklisted. This is interesting if the
+# Reformat files which are not excluded. This is interesting if the
# clang-format version or config changes.
# -n allows just listing the formatted files.
@@ -16,7 +16,7 @@ use ClangFormat;
my $clang_format = ClangFormat::find();
my $src = ClangFormat::get_extension_regex();
-my $blacklist_names = ClangFormat::get_blacklist();
+my $excluded_list_names = ClangFormat::get_excludelist();
my @filenames = ();
my $dry_run = 0;
@@ -25,7 +25,7 @@ open (FILES, "git ls-files |") || die "Cannot run git ls-files.";
while (my $filename = <FILES>)
{
chomp $filename;
- if ($filename =~ /\.($src)$/ and !exists($blacklist_names->{$filename}))
+ if ($filename =~ /\.($src)$/ and !exists($excluded_list_names->{$filename}))
{
push @filenames, $filename;
}
diff --git a/solenv/gbuild/extensions/post_GbuildToJson.mk b/solenv/gbuild/extensions/post_GbuildToJson.mk
index 7f05392e1179..708de742fffb 100644
--- a/solenv/gbuild/extensions/post_GbuildToJson.mk
+++ b/solenv/gbuild/extensions/post_GbuildToJson.mk
@@ -18,9 +18,9 @@
# --JAVAOBJECTS
# --PYTHONOBJECTS
#
-# Add black listed modules a json files (--BLACKLIST)
+# Add black listed modules a json files (--DENYLIST)
#
-# Reduce number of blacklisted modules
+# Reduce number of denylisted modules
ifneq ($(filter gbuildtojson,$(MAKECMDGOALS)),)
@@ -186,7 +186,7 @@ endef
gb_Module_add_l10n_target =
-gb_GbuildToJson_BLACKLISTEDMODULES := cli_ure jurt external
+gb_GbuildToJson_DENYLISTEDMODULES := cli_ure jurt external
define gb_Module__add_moduledir_impl
include $(patsubst $(1):%,%,$(filter $(1):%,$(gb_Module_MODULELOCATIONS)))/$(2)/Module_$(notdir $(2)).mk
@@ -196,7 +196,7 @@ gb_Module_TARGETSTACK := $$(wordlist 2,$$(words $$(gb_Module_TARGETSTACK)),$$(gb
endef
define gb_Module_add_moduledir
-$(if $(filter $(gb_GbuildToJson_BLACKLISTEDMODULES),$(2)),,$(call gb_Module__add_moduledir_impl,$(1),$(2)))
+$(if $(filter $(gb_GbuildToJson_DENYLISTEDMODULES),$(2)),,$(call gb_Module__add_moduledir_impl,$(1),$(2)))
endef
diff --git a/solenv/clang-format/ClangFormat.pm b/solenv/clang-format/ClangFormat.pm
index 5aba53fd285c..30f3816231bf 100644
--- a/solenv/clang-format/ClangFormat.pm
+++ b/solenv/clang-format/ClangFormat.pm
@@ -9,33 +9,33 @@ package ClangFormat;
use strict;
use warnings;
-our @EXPORT_OK = qw(get_blacklist set_blacklist get_wanted_version get_own_directory get_extension_regex find check_style);
+our @EXPORT_OK = qw(get_excludelist set_excludelist get_wanted_version get_own_directory get_extension_regex find check_style);
-# Reads the blacklist.
-sub get_blacklist()
+# Reads the excludelist.
+sub get_excludelist()
{
my $src = "c|cpp|cxx|h|hxx|inl";
- my %blacklist_names = ();
+ my %excludelist_names = ();
- # Read the blacklist.
- if (open(LINES, "solenv/clang-format/blacklist"))
+ # Read the excludelist.
+ if (open(LINES, "solenv/clang-format/excludelist"))
{
while (my $line = <LINES>)
{
chomp $line;
- $blacklist_names{$line} = 1;
+ $excludelist_names{$line} = 1;
}
}
- return \%blacklist_names;
+ return \%excludelist_names;
}
# Writes the blacklist.
# The single argument is a reference to an array.
-sub set_blacklist
+sub set_excludelist
{
my @filenames = @{$_[0]};
- open my $fh, ">", "solenv/clang-format/blacklist" or die $!;
+ open my $fh, ">", "solenv/clang-format/excludelist" or die $!;
print $fh "$_\n" for @filenames;
close $fh;
}
@@ -9,33 +9,33 @@ package ClangFormat;
}
-# Writes the blacklist.
+# Writes the excludelist.
# The single argument is a reference to an array.